import semver from "semver";
import pico from "picocolors";
import updateNotifier from "update-notifier";
import gstring from "gradient-string";
const checkNodeVersion = (wanted, name) => {
  if (!semver.satisfies(process.version, wanted, { includePrerelease: true })) {
    console.log(
      pico.red(
        `You are using Node ${process.version} , but this version of ${name} requires Node ${wanted}.
           Please upgrade your Node version.`
      )
    );
    process.exit(1);
  }
};
const checkUpdate = (pkg) => {
  updateNotifier({
    pkg,
    shouldNotifyInNpmScript: true
  }).notify({
    message: "Update available " + pico.dim("{currentVersion}") + pico.reset(" \u2192 ") + pico.green("{latestVersion}") + " \nRun " + pico.cyan(`pnpm update {packageName}@{latestVersion}`) + " to update",
    defer: false
  });
};
const gs = (str, options = [
  { color: "#42d392", pos: 0 },
  { color: "#42d392", pos: 0.1 },
  { color: "#647eff", pos: 1 }
]) => {
  if (process.stdout.isTTY && process.stdout.getColorDepth() > 8) {
    return gstring(options)(str);
  } else {
    return str;
  }
};
export {
  checkNodeVersion,
  checkUpdate,
  gs
};
